#
# spec file for package python-pysvn
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pysvn
Version:        1.9.6
Release:        bp154.1.50
Summary:        Highlevel Subversion Python Bindings
License:        Apache-1.1
Group:          Development/Libraries/Python
URL:            http://pysvn.tigris.org
Source0:        http://pysvn.barrys-emacs.org/source_kits/pysvn-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pycxx-devel}
BuildRequires:  %{python_module xml}
BuildRequires:  gcc-c++
BuildRequires:  libapr1-devel
BuildRequires:  libcom_err-devel
BuildRequires:  libcom_err2
BuildRequires:  libexpat-devel
BuildRequires:  neon-devel
BuildRequires:  python-rpm-macros
BuildRequires:  subversion-devel
Requires:       neon
Requires:       subversion
%python_subpackages

%description
pysvn is a set of highlevel Python bindings to Subversion. pysvn
enables tools to be written in Python that use Subversion.

Features:
 * Supports all svn client features
 * Supports svn transaction features required to write svn pre-commit
   hooks
 * Python like interface
 * Documentation and examples provided
 * No need to understand the Subversion C API

%prep
%setup -q -n pysvn-%{version}

%build
export CFLAGS="%{optflags}"
%{python_expand cp -r Source Source-%{$python_bin_suffix}
pushd Source-%{$python_bin_suffix}
$python setup.py backport
$python setup.py configure \
    --enable-debug --verbose --fixed-module-name --norpath \
    --pycxx-dir=%{$python_sysconfig_path include}/ --pycxx-src-dir=%{_datadir}/python%{$python_bin_suffix}/CXX
sed -i -e 's@-Wall -fPIC -fexceptions -frtti@%{optflags} -fPIC -frtti@' Makefile
make %{?_smp_mflags}
popd
}

%install
%{python_expand mkdir -p %{buildroot}/%{$python_sitearch}/pysvn
pushd Source-%{$python_bin_suffix}
cp pysvn/{__init__.py,_pysvn*.so} %{buildroot}/%{$python_sitearch}/pysvn
$python -m compileall -d %{$python_sitearch} %{buildroot}/%{$python_sitearch}/pysvn
$python -O -m compileall -d %{$python_sitearch} %{buildroot}/%{$python_sitearch}/pysvn
popd
}
rm -f Docs/generate_cpp_docs_from_html_docs.py

%check
cd Tests
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} PYTHON=$python make %{?_smp_mflags} || :

%files %{python_files}
%license LICENSE.txt
%doc Docs Examples
%{python_sitearch}/*

%changelog
* Thu Aug  9 2018 tchvatal@suse.com
- Update to 1.9.6:
  * No real obvious changelog
  * Support python 3.7
* Thu Sep  7 2017 jengelh@inai.de
- Ensure neutrality of description.
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to version 1.9.4
- Remove bnc445431_pysvn_svnenv.cpp.diff
  * No longer needed
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Fri Sep 18 2015 astieger@suse.com
- update to 1.8.0:
  * Support python3 sorting of list of PysvnDict objects that name
    a known "key".
  * Support Subversion 1.9.1.
  * Support Python 3.5
  * Fix issue: is_versioned is always 0
  * Fix issue: svn_client_root_url_from_path() would crash if login
    callback was called.
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 1.7.8
  + No changelog available
* Wed Jul 31 2013 hpj@urpla.net
- update to 1.7.7
  * no degestible changelog provided from upstream
* Thu Nov 22 2012 robert.munteanu@gmail.com
- Added patch for bnc#780243, cherry-picked from upstream r1742
* Mon Apr 30 2012 cfarrell@suse.com
- license update: Apache-1.1
  See LICENSE.txt (most of the package is in fact BSD-3-Clause licensed"
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4
* Thu Apr 26 2012 toddrme2178@gmail.com
- Add python 3 package
* Sun Mar  4 2012 coolo@suse.com
- update to 1.7.6:
  * supports subversion 1.7.3 (and earlier)
* Wed Feb  1 2012 saschpe@suse.de
- Ran spec-cleaner
* Mon Oct 31 2011 dmueller@suse.de
- update to 1.7.5:
  * update included pycss to 0.6 to build against subversion 1.7
* Thu Aug 19 2010 toms@suse.de
- Update to version 1.7.4
  * bug fixes for reported issues
* Sat May 29 2010 toms@suse.de
- Update to version 1.7.2
* Sat Jan 23 2010 jengelh@medozas.de
- enable parallel build
* Sat Aug  8 2009 hpj@urpla.net
- update to version 1.7.0
  switch to the authors recommended way to build/install this thing
* Sun Nov 23 2008 coolo@suse.de
- readd the second last change
* Tue Nov 18 2008 toms@suse.de
- Fixed bnc#445431 "undefinied C++ code"
  in pysvn_svnenv.cpp
* Wed Oct 29 2008 ro@suse.de
- fix typo in specfile
- remove doc files from INSTALLED_FILES
* Wed Oct 22 2008 toms@suse.de
- renamed macro _realname
* Thu Sep 25 2008 toms@suse.de
- Taken from home:/termim into factory
* Thu Aug  7 2008 Mikhail Terekhov <termim@gmail.com>
- Version 1.6.0 setup.py
* Wed Feb 28 2007 Jérôme Soyer <saispo@mandriva.org>
- Revision: 130370
- New release
  Bogdano Arendartchuk <bogdano@mandriva.com>
  - fix after version upgrade)
* Tue Dec  5 2006 Jérôme Soyer <saispo@mandriva.org>
- Revision: 91597
- Remove patch and update
- Rebuild for latest pyhton
  + Bogdano Arendartchuk <bogdano@mandriva.com>
  - Import python-pysvn
